@@ -4,7 +4,7 @@ package App::SFDC::Command::Deploy;
 use strict;
 use warnings;
 
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.18'; # VERSION
 
 use Data::Dumper;
 use File::Find 'find';
@@ -146,7 +146,7 @@ has '_result',
 
 sub _JUnitOutput {
     my $self = shift;
-    return unless $self->testoutput;
+    return unless $self->testoutput and $self->runtests;
     Role::Tiny->apply_roles_to_object(
         $self->_result,
         'App::SFDC::Role::DeployResult::JUnitOutput'
@@ -178,7 +178,7 @@ App::SFDC::Command::Deploy - Deploy files to SFDC
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 OPTIONS
 
